yt.utilities.object\_registries module
======================================

.. automodule:: yt.utilities.object_registries
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
